@@ -14,24 +14,17 @@
 #    under the License.
 
 import copy
-import datetime
 import os
 
 import fixtures
+import mock
 from oslo_utils import strutils
+import requests
 import six
 import testtools
 
-from ironicclient.common import http
-
-
-DEFAULT_TEST_HOST = 'localhost'
-DEFAULT_TEST_REGION = 'regionhost'
-DEFAULT_TEST_PORT = '6385'
-
 
 class BaseTestCase(testtools.TestCase):
-
     def setUp(self):
         super(BaseTestCase, self).setUp()
         self.useFixture(fixtures.FakeLogger())
@@ -58,7 +51,7 @@ class FakeAPI(object):
 
     def raw_request(self, *args, **kwargs):
         response = self._request(*args, **kwargs)
-        body_iter = http.ResponseBodyIterator(six.StringIO(response[1]))
+        body_iter = iter(six.StringIO(response[1]))
         return FakeResponse(response[0]), body_iter
 
     def json_request(self, *args, **kwargs):
@@ -86,7 +79,7 @@ class FakeConnection(object):
 
 class FakeResponse(object):
     def __init__(self, headers, body=None, version=None, status=None,
-                 reason=None):
+                 reason=None, request_headers={}):
         """Fake object to help testing.
 
         :param headers: dict representing HTTP response headers
@@ -94,9 +87,12 @@ class FakeResponse(object):
         """
         self.headers = headers
         self.body = body
-        self.version = version
-        self.status = status
+        self.raw = mock.Mock()
+        self.raw.version = version
+        self.status_code = status
         self.reason = reason
+        self.request = mock.Mock()
+        self.request.headers = request_headers
 
     def getheaders(self):
         return copy.deepcopy(self.headers).items()
@@ -108,50 +104,36 @@ class FakeResponse(object):
         return self.body.read(amt)
 
     def __repr__(self):
-        return ("FakeResponse(%s, body=%s, version=%s, status=%s, reason=%s)" %
-                (self.headers, self.body, self.version, self.status,
-                 self.reason))
+        return ("FakeResponse(%s, body=%s, version=%s, status=%s, reason=%s, "
+                "request_headers=%s)" %
+                (self.headers, self.body, self.raw.version, self.status_code,
+                 self.reason, self.request.headers))
 
 
-class FakeServiceCatalog(object):
-    def url_for(self, endpoint_type, service_type, attr=None,
-                filter_value=None):
-        if attr == 'region' and filter_value:
-            return 'http://%s:%s/v1/f14b41234' % (DEFAULT_TEST_REGION,
-                                                  DEFAULT_TEST_PORT)
-        else:
-            return 'http://%s:%s/v1/f14b41234' % (DEFAULT_TEST_HOST,
-                                                  DEFAULT_TEST_PORT)
+def mockSessionResponse(headers, content=None, status_code=None, version=None,
+                        request_headers={}):
+    raw = mock.Mock()
+    raw.version = version
+    request = mock.Mock()
+    request.headers = request_headers
+    response = mock.Mock(spec=requests.Response,
+                         headers=headers,
+                         content=content,
+                         status_code=status_code,
+                         raw=raw,
+                         reason='',
+                         encoding='UTF-8',
+                         request=request)
+    response.text = content
+
+    return response
 
 
-class FakeKeystone(object):
-    service_catalog = FakeServiceCatalog()
-    timestamp = datetime.datetime.utcnow() + datetime.timedelta(days=5)
+def mockSession(headers, content=None, status_code=None, version=None):
+    session = mock.Mock(spec=requests.Session,
+                        verify=False,
+                        cert=('test_cert', 'test_key'))
+    response = mockSessionResponse(headers, content, status_code, version)
+    session.request = mock.Mock(return_value=response)
 
-    def __init__(self, auth_token):
-        self.auth_token = auth_token
-        self.auth_ref = {
-            'token': {'expires': FakeKeystone.timestamp.strftime(
-                      '%Y-%m-%dT%H:%M:%S.%f'),
-                      'id': 'd1a541311782870742235'}
-        }
-
-
-class FakeSessionResponse(object):
-
-    def __init__(self, headers, content=None, status_code=None):
-        self.headers = headers
-        self.content = content
-        self.status_code = status_code
-
-
-class FakeSession(object):
-
-    def __init__(self, headers, content=None, status_code=None):
-        self.headers = headers
-        self.content = content
-        self.status_code = status_code
-
-    def request(self, url, method, **kwargs):
-        return FakeSessionResponse(self.headers, self.content,
-                                   self.status_code)
+    return session
